==> cutemaze_1.3.3.orig.tar.gz: cutemaze-1.3.3/translations/cutemaze_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="it" version="2.1">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Spiacenti</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Impossibile caricare il gioco precedente. Verrà avviato un nuovo gioco.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 trascorso</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Success</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Paused</source>
        <translation>In pausa</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Controllo</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Opzione</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleziona la lingua dell&apos;applicazione:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Riavvia l&apos;applicazione per rendere effettive le modifiche alla lingua.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nuovo Gioco</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kruskal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prim</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Stack</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Stack 2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Stack 3</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Stack 4</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Stack 5</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmo:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Score</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Passi</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritmo</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Congratulazioni!</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Well done!</source>
        <translation>Ben fatto!</translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Gioco</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Mostra il tempo trascorso</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controlli</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Move Down:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Move Left:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Move Right:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Themes</source>
        <translation>Temi</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sorry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Rimuovere il tema selezionato?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Impossibile rimuovere il tema selezionato.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Informazioni &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Gioco</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Impostazioni</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Applicazione &amp;Lingua...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferenze...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Informazioni</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Rilasciato sotto &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Le icone sono dell&apos; &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Utilizzato sotto la &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
</context>
</TS>

==> cutemaze_1.3.4.orig.tar.gz: cutemaze-1.3.4/translations/cutemaze_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Spiacenti</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Impossibile caricare il gioco precedente. Verrà avviato un nuovo gioco.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 trascorso</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Success</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>In pausa</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Controllo</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Opzione</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleziona la lingua dell&apos;applicazione:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Riavvia l&apos;applicazione per rendere effettive le modifiche alla lingua.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nuovo Gioco</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prim</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stack</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmo:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Score</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Passi</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritmo</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Congratulazioni!</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation>Ben fatto!</translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Gioco</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Mostra il tempo trascorso</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controlli</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Temi</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation type="unfinished">Spiacenti</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Rimuovere il tema selezionato?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Impossibile rimuovere il tema selezionato.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Informazioni &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Gioco</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Impostazioni</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Applicazione &amp;Lingua...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferenze...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Informazioni</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Rilasciato sotto &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Le icone sono dell&apos; &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Utilizzato sotto la &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
</context>
</TS>
